[Scummvm-cvs-logs] SF.net SVN: scummvm:[53762] scummvm/trunk

fingolfin at users.sourceforge.net fingolfin at users.sourceforge.net
Sun Oct 24 15:04:33 CEST 2010


Revision: 53762
          http://scummvm.svn.sourceforge.net/scummvm/?rev=53762&view=rev
Author:   fingolfin
Date:     2010-10-24 13:04:33 +0000 (Sun, 24 Oct 2010)

Log Message:
-----------
ALL: Fix various typos (patch #3093266)

Modified Paths:
--------------
    scummvm/trunk/base/main.cpp
    scummvm/trunk/common/unzip.cpp
    scummvm/trunk/engines/advancedDetector.cpp
    scummvm/trunk/engines/cruise/dataLoader.cpp
    scummvm/trunk/engines/lure/debugger.cpp
    scummvm/trunk/engines/saga/introproc_ite.cpp
    scummvm/trunk/engines/scumm/debugger.cpp
    scummvm/trunk/engines/scumm/insane/insane_ben.cpp
    scummvm/trunk/engines/scumm/insane/insane_enemy.cpp
    scummvm/trunk/graphics/video/flic_decoder.cpp
    scummvm/trunk/sound/decoders/flac.cpp
    scummvm/trunk/sound/mods/tfmx.cpp
    scummvm/trunk/sound/softsynth/cms.cpp

Modified: scummvm/trunk/base/main.cpp
===================================================================
--- scummvm/trunk/base/main.cpp	2010-10-24 13:00:47 UTC (rev 53761)
+++ scummvm/trunk/base/main.cpp	2010-10-24 13:04:33 UTC (rev 53762)
@@ -310,7 +310,7 @@
 	Common::StringMap settings;
 	command = Base::parseCommandLine(settings, argc, argv);
 
-	// Load the config file (possibly overriden via command line):
+	// Load the config file (possibly overridden via command line):
 	if (settings.contains("config")) {
 		ConfMan.loadConfigFile(settings["config"]);
 		settings.erase("config");

Modified: scummvm/trunk/common/unzip.cpp
===================================================================
--- scummvm/trunk/common/unzip.cpp	2010-10-24 13:00:47 UTC (rev 53761)
+++ scummvm/trunk/common/unzip.cpp	2010-10-24 13:04:33 UTC (rev 53762)
@@ -401,7 +401,7 @@
 /* ===========================================================================
      Read a byte from a gz_stream; update next_in and avail_in. Return EOF
    for end of file.
-   IN assertion: the stream s has been sucessfully opened for reading.
+   IN assertion: the stream s has been successfully opened for reading.
 */
 
 

Modified: scummvm/trunk/engines/advancedDetector.cpp
===================================================================
--- scummvm/trunk/engines/advancedDetector.cpp	2010-10-24 13:00:47 UTC (rev 53761)
+++ scummvm/trunk/engines/advancedDetector.cpp	2010-10-24 13:04:33 UTC (rev 53762)
@@ -622,7 +622,7 @@
 				matchedDesc = agdesc;
 				maxNumMatchedFiles = numMatchedFiles;
 
-				debug(4, "and overriden");
+				debug(4, "and overridden");
 			}
 		}
 	}

Modified: scummvm/trunk/engines/cruise/dataLoader.cpp
===================================================================
--- scummvm/trunk/engines/cruise/dataLoader.cpp	2010-10-24 13:00:47 UTC (rev 53761)
+++ scummvm/trunk/engines/cruise/dataLoader.cpp	2010-10-24 13:04:33 UTC (rev 53762)
@@ -55,7 +55,7 @@
 		break;
 
 	default:
-		error("Unkown gfx format %d", format);
+		error("Unknown gfx format %d", format);
 	}
 
 	uint8 *buffer = (uint8 *)MemAlloc(spriteSize);

Modified: scummvm/trunk/engines/lure/debugger.cpp
===================================================================
--- scummvm/trunk/engines/lure/debugger.cpp	2010-10-24 13:00:47 UTC (rev 53761)
+++ scummvm/trunk/engines/lure/debugger.cpp	2010-10-24 13:04:33 UTC (rev 53762)
@@ -323,7 +323,7 @@
 
 		if (h != NULL) {
 			DebugPrintf("Frame Number = %d of %d\n", h->frameNumber(), h->numFrames());
-			DebugPrintf("Persistant = %s\n", h->persistant() ? "true" : "false");
+			DebugPrintf("Persistent = %s\n", h->persistant() ? "true" : "false");
 		}
 
 	} else if (strcmp(argv[2], "actions") == 0) {

Modified: scummvm/trunk/engines/saga/introproc_ite.cpp
===================================================================
--- scummvm/trunk/engines/saga/introproc_ite.cpp	2010-10-24 13:00:47 UTC (rev 53761)
+++ scummvm/trunk/engines/saga/introproc_ite.cpp	2010-10-24 13:04:33 UTC (rev 53762)
@@ -485,7 +485,7 @@
 		break;
 
 	default:
-		warning("Illegal scene procedure paramater");
+		warning("Illegal scene procedure parameter");
 		break;
 	}
 
@@ -589,7 +589,7 @@
 	case SCENE_END:
 		break;
 	default:
-		warning("Illegal scene procedure paramater");
+		warning("Illegal scene procedure parameter");
 		break;
 	}
 
@@ -694,7 +694,7 @@
 	case SCENE_END:
 		break;
 	default:
-		warning("Illegal scene procedure paramater");
+		warning("Illegal scene procedure parameter");
 		break;
 	}
 
@@ -812,7 +812,7 @@
 	case SCENE_END:
 		break;
 	default:
-		warning("Illegal scene procedure paramater");
+		warning("Illegal scene procedure parameter");
 		break;
 	}
 

Modified: scummvm/trunk/engines/scumm/debugger.cpp
===================================================================
--- scummvm/trunk/engines/scumm/debugger.cpp	2010-10-24 13:00:47 UTC (rev 53761)
+++ scummvm/trunk/engines/scumm/debugger.cpp	2010-10-24 13:04:33 UTC (rev 53762)
@@ -529,7 +529,7 @@
 	} else {
 		DebugPrintf("Usage: debug [+CHANNEL|-CHANNEL]\n");
 		DebugPrintf("Enables or disables the given debug channel.\n");
-		DebugPrintf("When used without parameters, lists all avaiable debug channels and their status.\n");
+		DebugPrintf("When used without parameters, lists all available debug channels and their status.\n");
 	}
 
 	return true;

Modified: scummvm/trunk/engines/scumm/insane/insane_ben.cpp
===================================================================
--- scummvm/trunk/engines/scumm/insane/insane_ben.cpp	2010-10-24 13:00:47 UTC (rev 53761)
+++ scummvm/trunk/engines/scumm/insane/insane_ben.cpp	2010-10-24 13:04:33 UTC (rev 53762)
@@ -1163,7 +1163,7 @@
 			setBenState();
 			_actor[0].act[2].tilt = 0;
 			// for some reason there is no break at this
-			// place, so tilt gets overriden on next line
+			// place, so tilt gets overridden on next line
 		}
 		_actor[0].act[2].tilt = calcTilt(_actor[0].tilt);
 		break;

Modified: scummvm/trunk/engines/scumm/insane/insane_enemy.cpp
===================================================================
--- scummvm/trunk/engines/scumm/insane/insane_enemy.cpp	2010-10-24 13:00:47 UTC (rev 53761)
+++ scummvm/trunk/engines/scumm/insane/insane_enemy.cpp	2010-10-24 13:04:33 UTC (rev 53762)
@@ -2072,7 +2072,7 @@
 			setEnemyState();
 			_actor[1].act[2].tilt = 0;
 			// for some reason there is no break at this
-			// place, so tilt gets overriden on next line
+			// place, so tilt gets overridden on next line
 		}
 		_actor[1].act[2].tilt = calcTilt(_actor[1].tilt);
 		break;

Modified: scummvm/trunk/graphics/video/flic_decoder.cpp
===================================================================
--- scummvm/trunk/graphics/video/flic_decoder.cpp	2010-10-24 13:00:47 UTC (rev 53761)
+++ scummvm/trunk/graphics/video/flic_decoder.cpp	2010-10-24 13:04:33 UTC (rev 53762)
@@ -70,7 +70,7 @@
 	}
 
 	_fileStream->readUint16LE();	// flags
-	// Note: The normal delay is a 32-bit integer (dword), whereas the overriden delay is a 16-bit integer (word)
+	// Note: The normal delay is a 32-bit integer (dword), whereas the overridden delay is a 16-bit integer (word)
 	// the frame delay is the FLIC "speed", in milliseconds.
 	_frameRate = Common::Rational(1000, _fileStream->readUint32LE());
 
@@ -207,7 +207,7 @@
 			// this properly.
 
 			chunkCount = _fileStream->readUint16LE();
-			// Note: The overriden delay is a 16-bit integer (word), whereas the normal delay is a 32-bit integer (dword)
+			// Note: The overridden delay is a 16-bit integer (word), whereas the normal delay is a 32-bit integer (dword)
 			// the frame delay is the FLIC "speed", in milliseconds.
 			uint16 newFrameDelay = _fileStream->readUint16LE();	// "speed", in milliseconds
 			if (newFrameDelay > 0)

Modified: scummvm/trunk/sound/decoders/flac.cpp
===================================================================
--- scummvm/trunk/sound/decoders/flac.cpp	2010-10-24 13:00:47 UTC (rev 53761)
+++ scummvm/trunk/sound/decoders/flac.cpp	2010-10-24 13:04:33 UTC (rev 53762)
@@ -303,7 +303,7 @@
 	const uint numChannels = getChannels();
 
 	if (numChannels == 0) {
-		warning("FLACStream: Stream not sucessfully initialised, cant playback");
+		warning("FLACStream: Stream not successfully initialised, cant playback");
 		return -1; // streaminfo wasnt read!
 	}
 

Modified: scummvm/trunk/sound/mods/tfmx.cpp
===================================================================
--- scummvm/trunk/sound/softsynth/cms.cpp	2010-10-24 13:00:47 UTC (rev 53761)
+++ scummvm/trunk/sound/softsynth/cms.cpp	2010-10-24 13:04:33 UTC (rev 53762)
@@ -342,7 +342,7 @@
 		default:
 			// The CMS allows all registers to be written, so we just output some debug
 			// message here
-			debug(5, "CMS Unkown write to reg %x with %x",reg, data);
+			debug(5, "CMS Unknown write to reg %x with %x",reg, data);
 	}
 }
 


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list
--- scummvm/trunk/sound/mods/tfmx.cpp	2010-10-24 13:00:47 UTC (rev 53761)
+++ scummvm/trunk/sound/mods/tfmx.cpp	2010-10-24 13:04:33 UTC (rev 53762)
@@ -281,7 +281,7 @@
 			continue;
 
 		case 0x04:	// Wait. Parameters: Ticks to wait(W).
 			// TODO: some unkown Parameter? (macroPtr[1] & 1)
 			channel.macroWait = READ_BE_UINT16(&macroPtr[2]);
 			break;
 
@@ -1154,7 +1154,7 @@
 	if (macroData[0] < ARRAYSIZE(tableMacros))
 		debug("%s %02X%02X%02X", tableMacros[macroData[0]], macroData[1], macroData[2], macroData[3]);
 	else
-		debug("Unkown Macro #%02X %02X%02X%02X", macroData[0], macroData[1], macroData[2], macroData[3]);
+		debug("Unknown Macro #%02X %02X%02X%02X", macroData[0], macroData[1], macroData[2], macroData[3]);
 }
 
 void displayPatternstep(const void * const vptr) {
@@ -281,7 +281,7 @@
 
 		case 0x04:	// Wait. Parameters: Ticks to wait(W).
-			// TODO: some unkown Parameter? (macroPtr[1] & 1)
+			// TODO: some unknown Parameter? (macroPtr[1] & 1)
 			channel.macroWait = READ_BE_UINT16(&macroPtr[2]);
 			break;

Modified: scummvm/trunk/sound/softsynth/cms.cpp
===================================================================